@@ -71,8 +71,8 @@ class TorchFitter:
         # Optimizer object
         self.optimizer = optimizer
 
+        # Scheduler Object
         self.scheduler = scheduler
-
         self.validation_scheduler = validation_scheduler  # do scheduler.step after validation stage loss
         self.step_scheduler = step_scheduler  # do scheduler.step after optimizer.step
         self.log(f'Fitter prepared. Device is {self.device}')
@@ -118,9 +118,9 @@ class TorchFitter:
             history['lr'] = self.optimizer.param_groups[0]['lr']
 
             # Print validation results
-            self.log(f'[RESULT]: Val. Epoch: {self.epoch}, summary_loss: {summary_loss.avg:.5f}, ' +\
-                f'metric {calculated_metric},' if calculated_metric else '' +\
-                f'time: {(time.time() - t):.5f}')
+            self.log(f'[RESULT]: Valid. Epoch: {self.epoch}, summary_loss: {summary_loss.avg:.5f}, ' +\
+                     f'metric {calculated_metric},' if calculated_metric else '' +\
+                     f'time: {(time.time() - t):.5f}')
 
             if calculated_metric:
                 history['val_metric'] = calculated_metric
@@ -132,15 +132,12 @@ class TorchFitter:
                     ((early_stopping_mode == 'min') and (calculated_metric < self.best_metric))))
                 or
                 ((metric is None) and (calculated_metric < self.best_metric))):
-                    savepath = f'{self.base_dir}/best-checkpoint-{str(self.epoch).zfill(3)}epoch.bin'
-                    self.log(f'Validation metric improved from {self.best_metric} to '
-                                 f'{calculated_metric} and model is saved to {savepath}')
+                    self.log(f'Validation metric improved from {self.best_metric} to {calculated_metric}')
                     self.best_metric = calculated_metric
                     self.model.eval()
                     if save_checkpoint:
+                        savepath = f'{self.base_dir}/best-checkpoint.bin'
                         self.save(savepath)
-                    for path in sorted(glob(f'{self.base_dir}/best-checkpoint-*epoch.bin'))[:-3]:
-                        os.remove(path)
                     es_epochs = 0  # reset early stopping count
             else:
                 es_epochs += 1  # increase epoch count with no improvement, for early stopping check
@@ -244,6 +241,7 @@ class TorchFitter:
         input:
             path: path of the file to be saved
         """
+        self.log(f'Model is saved to {path}')
         self.model.eval()
         torch.save({
                 'model_state_dict': self.model.state_dict(),
